$formmethod top-level constant

Attribute const $formmethod

If the button/input is a submit button, this attribute sets the submission method to use during form submission (GET, POST, etc.). If this attribute is specified, it overrides the method attribute of the button's form owner.

Implementation

const $formmethod = Attribute("formmethod");