RawAttributeComponent class final

Inheritance
Available extensions

Constructors

RawAttributeComponent(String name, String? content)
const

Properties

content String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(HtmlComponent c) HtmlComponent
inherited
addAll(List<HtmlComponent> cs) HtmlComponent
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toHtml() String

Available on HtmlComponent, provided by the HtmlComponentToHtml extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited