kbd top-level constant

Tag const kbd

Represents a span of inline text denoting textual user input from a keyboard, voice input, or any other text entry device.

Implementation

const kbd = Tag("kbd");