label top-level constant
Tag
const label
Represents a caption for an item in a user interface.
Implementation
const label = Tag("label");
Represents a caption for an item in a user interface.
const label = Tag("label");