section top-level constant

Tag const section

Represents a generic standalone section of a document, which doesn't have a more specific semantic element to represent it. Sections should always have a heading, with very few exceptions.

Implementation

const section = Tag("section");