varTag top-level constant
Tag
const varTag
Represents the name of a variable in a mathematical expression or a programming context.
Implementation
const varTag = Tag("var");
Represents the name of a variable in a mathematical expression or a programming context.
const varTag = Tag("var");